Release Notes
==============

.. changelog::
   :github: https://github.com/cascode-labs/virtue/releases
   :pypi: https://pypi.org/project/virtue-skill/
   :changelog-url: http://www.cascode-labs.org/virtue/overview/release_notes.html
